@@ -5,6 +5,7 @@ package domain
 
 import (
 	"context"
+	"encoding/json"
 	"time"
 )
 
@@ -61,6 +62,19 @@ type Feed struct {
 	Proxy    *Proxy
 }
 
+func (f Feed) MarshalJSON() ([]byte, error) {
+	type Alias Feed
+	return json.Marshal(&struct {
+		*Alias
+		APIKey string `json:"api_key"`
+		Cookie string `json:"cookie"`
+	}{
+		APIKey: RedactString(f.ApiKey),
+		Cookie: RedactString(f.Cookie),
+		Alias:  (*Alias)(&f),
+	})
+}
+
 type FeedSettingsJSON struct {
 	DownloadType FeedDownloadType `json:"download_type"`
 }
